function [x_in,y_in, x_out, y_out, intg] = rand_integrate(func,y_min, y_max, x_min, x_max, num_pts)

% Integrate function by generating random points
%
%
% 
% Inputs:
% 
% func - handle to integrand function
% 
% y_min - minimum value of function
% 
% y_max - maximum value of function
% 
% x_min - left bound for integration
% 
% x_max - right bound for integration
% 
% num_pts - number of points to generate
% 
% 
% 
% Outputs:
% 
% x_in - x coordinates for randomly generated points inside the curve
% 
% y_in - y coordinates for randomly generated points inside the curve
% 
% x_out - x coordinates for randomly generated points outside the curve
% 
% y_out - y coordinates for randomly generated points outside the curve
% 
% intg - the area under the curve

if y_min < 0
    error('Negative y_min values currently not supported')
end

x_in = [];
y_in = [];
x_out = [];
y_out = [];

for i = 1:num_pts
    x_i = get_rand_pt(x_min, x_max);
    y_i = get_rand_pt(y_min, y_max);
    
    %You should preallocate arrays for better performance
    if y_i < func(x_i)
        x_in = [x_in x_i];
        y_in = [y_in y_i];
    else
        x_out = [x_out x_i];
        y_out = [y_out y_i];
    end

end

    
x_width = x_max - x_min;
y_width = y_max - y_min;

num_inside_pts = length(x_in);

intg = num_inside_pts / num_pts * x_width * y_width;