function [bin_midpts, bin_counts] = sample_walks(num_walks, num_steps, step_size, num_bins)

% Generate a sample of random walks and return a histogram of their 
% displacements
% 
% Inputs:
%
% num_walks - number of walks
% 
% num_steps - number of steps per walk
% 
% step_size - magnitude of step (always positive)
%
% num_bins - number of bins in the output histogram
% 
%
%
% Outputs:
% 
% disp - total 1D displacement (positive or negative)


% Get the absolute value of the maximum displacement
max_disp = step_size * num_steps;

% Get the bin_edges
bin_edges = linspace(-max_disp, max_disp, num_bins+1);

% Compute the midpoints of the bins in the histogram
bin_midpts = (bin_edges(2:num_bins+1) + bin_edges(1:num_bins)) / 2;

% Take a series of random walks and record the displacements
disp_sample = zeros(1,num_walks);
for i = 1:num_walks
    disp_sample(i) = take_walk(num_steps, step_size);
end

% Make a histogram of the displacements
bin_counts = histc(disp_sample, bin_edges(1:num_bins));